Uncompress a raw GZIP stream
Arguments
- buffer
Raw vector, containing the data to uncompress.
- pos
Start position of data to uncompress in
buffer.- size
Uncompressed size estimate, or
NULL. If not given, or too small, the output buffer is resized multiple times.- raw
Whether
buffercontains a raw DEFLATE stream, i.e. one without a zlib header and trailer. The default (FALSE) expects a zlib stream.
Value
Named list with three entries:
output: raw vector, the uncompressed data,bytes_read: number of bytes used frombuffer,bytes_written: number of bytes written to the output buffer.
See also
base::memDecompress() does the same with type = "gzip",
but it does not tell you the number of bytes read from the input.