| unzip | R Documentation |
unzip() always restores modification times of the extracted files and
directories.
unzip(
zipfile,
files = NULL,
overwrite = TRUE,
junkpaths = FALSE,
exdir = ".",
encoding = NULL,
password = NULL
)
zipfile |
Path to the zip file to uncompress, or a character vector of
paths. When multiple paths are given and all other arguments are at their
defaults, the files are unzipped concurrently in a thread pool.
Set the |
files |
Character vector of files to extract from the archive.
Files within directories can be specified, but they must use a forward
slash as path separator, as this is what zip files use internally.
If |
overwrite |
Whether to overwrite existing files. If |
junkpaths |
Whether to ignore all directory paths when creating
files. If |
exdir |
Directory to uncompress the archive to. If it does not exist, it will be created. |
encoding |
Encoding to use for entry filenames. ZIP files signal
UTF-8 filenames via a flag in each entry; those are always decoded as
UTF-8 regardless of |
password |
Password for decrypting encrypted entries. It can be a
string, a raw vector, or a function that returns one of these. If |
A data frame with one row per extracted entry and columns,
invisibly: filename (path within the archive), compressed_size,
uncompressed_size, timestamp, permissions, crc32, offset,
type (same as in zip_list()), and path (absolute path to the
extracted file on disk).
If the zip archive stores permissions and was created on Unix, the permissions will be restored.
Other zip/unzip functions:
zip_list()
## temporary directory, to avoid messing up the user's workspace.
dir.create(tmp <- tempfile())
dir.create(file.path(tmp, "mydir"))
cat("first file", file = file.path(tmp, "mydir", "file1"))
cat("second file", file = file.path(tmp, "mydir", "file2"))
zipfile <- tempfile(fileext = ".zip")
zip::zip(zipfile, "mydir", root = tmp)
## List contents
zip_list(zipfile)
## Extract and inspect result
tmp2 <- tempfile()
result <- unzip(zipfile, exdir = tmp2)
result[, c("filename", "path")]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.